@@ -297,14 +297,14 @@ fn dump_bytecode(prog: &str, raw: &RawPrelude) -> String {
 fn main() {
     #[allow(unused_mut)]
     let mut app = App::new("frawk")
-        .version("0.4.2")
+        .version("0.4.4")
         .author("Eli R.")
         .about("frawk is a pattern scanning and (semi-structured) text processing language")
         .arg(Arg::new("program-file")
              .long("program-file")
              .short('f')
-             .multiple(true)
-             .number_of_values(1))
+             .takes_value(true)
+             .multiple_occurrences(true))
         .arg(Arg::new("opt-level")
              .long("opt-level")
              .short('O')
@@ -326,9 +326,10 @@ fn main() {
              .about("Input is split according to the rules of (csv|tsv). $0 contains the unescaped line. Assigning to columns does nothing."))
         .arg(Arg::new("var")
              .short('v')
-             .multiple(true)
+             .multiple_occurrences(true)
+             .multiple_values(true)
              .takes_value(true)
-             .number_of_values(1)
+             .min_values(1)
              .about("Has the form <identifier>=<chars>. A variable with the name <identifier> is assigned to an escaped string literal containing <chars> before the body of the frawk program is run."))
         .arg("-F, --field-separator=[SEPARATOR] 'Field separator for frawk program.'")
         .arg(Arg::new("backend")
@@ -347,7 +348,7 @@ fn main() {
         .arg(Arg::new("input-files")
              .about("Input files to be read by frawk program")
              .index(2)
-             .multiple(true))
+             .multiple_values(true))
         .arg(Arg::new("parallel-strategy")
              .about("Attempt to execute the script in parallel. Strategy r[ecord] parallelizes within the current input file. Strategy f[ile] parallelizes between input files.")
              .short('p')
